==> okuyama-0.3.zip: okuyama-0.3.0/TestSock.java <==
import java.util.*;
import java.io.*;
import java.net.*;

import org.imdst.client.ImdstKeyValueClient;
import org.batch.lang.BatchException;

public class TestSock {
    public static void main(String[] args) {
        try {
            if (args == null || args.length ==0) {

                System.out.println("{L[lŌJԂϓēo^}                        R}h{args[0]=1, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=o^}");
                System.out.println("{L[lŌJԂϓĎ擾}                        R}h{args[0]=2, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=擾}");
                System.out.println("{Tag4p^[ŎIɕϓăL[l͎ϓœo^}        R}h{args[0]=3, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=o^}");
                System.out.println("{w肵TagŊ֘AL[lw񐔎擾}                       R}h{args[0]=4, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=擾, args[4]=wTagl (tag1 or tag2 or tag3 or tag4)}");
                System.out.println("{w肵t@CoCif[^ƂĎw肵L[lŕۑ}  R}h{args[0]=5, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=o^, args[4]=t@CpX, args[5]=L[l}");
                System.out.println("{w肵L[lŃoCif[^擾ăt@C}          R}h{args[0]=6, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=擾, args[4]=쐬t@CpX, args[5]=L[l}");
                System.out.println("{L[lŌJԂϓč폜}                        R}h{args[0]=7, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=擾}");
                System.exit(0);
            }
            int port = Integer.parseInt(args[2]);

            if (args[0].equals("1")) {

                // ImdstKeyValueClientgpăf[^ۑ(TagȂ)

                // NCAgCX^X쐬
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();

                // }X^T[oɐڑ
                imdstKeyValueClient.connect(args[1], port);

Thread.sleep(100);
                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    // f[^o^
                    if (!imdstKeyValueClient.setValue("datasavekey_" + new Integer(i).toString(), "savedatavaluestr_" + new Integer(i).toString())) {
                        System.out.println("ImdstKeyValueClient - error");
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start) + "milli second");

                imdstKeyValueClient.close();
            } else if (args[0].equals("2")) {

                // ImdstKeyValueClientgpăf[^擾(Keŷ)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] ret = null;
Thread.sleep(100);
                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    ret = imdstKeyValueClient.getValue("datasavekey_" + new Integer(i).toString());
                    if (ret[0].equals("true")) {
                        // f[^L
                        System.out.println(ret[1]);
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start) + "milli second");

                imdstKeyValueClient.close();
            } else if (args[0].equals("2.1")) {

                // ImdstKeyValueClientgpăf[^擾(Keŷ)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] ret = null;

                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    ret = imdstKeyValueClient.getValue("datasavekey_" + new Integer(i).toString());
                    if (ret[0].equals("true")) {
                        // f[^L
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start) + "milli second");

                imdstKeyValueClient.close();

            } else if (args[0].equals("3")) {

                // ImdstKeyValueClientgpăf[^ۑ(Tag)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] tag1 = {"tag1"};
                String[] tag2 = {"tag1","tag2"};
                String[] tag3 = {"tag1","tag2","tag3"};
                String[] tag4 = {"tag4"};
                String[] setTag = null;
                int counter = 0;

                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    if (counter == 0) {
                        setTag = tag1;
                        counter++;
                    } else if (counter == 1) {
                        setTag = tag2;
                        counter++;
                    } else if (counter == 2) {
                        setTag = tag3;
                        counter++;
                    } else if (counter == 3) {
                        setTag = tag4;
                        counter = 0;
                    }

                    if (!imdstKeyValueClient.setValue("tagsampledatakey_" + new Integer(i).toString(), setTag, "tagsamplesavedata_" + new Integer(i).toString())) {
                        System.out.println("ImdstKeyValueClient - error");
                    }
                }

                imdstKeyValueClient.close();
			} else if (args[0].equals("3.1")) {

                // ImdstKeyValueClientgpăf[^ۑ(Tag)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] setTag = args[4].split(" ");

                int counter = 0;
				String keyStr = null;
				imdstKeyValueClient.setValue(args[3], setTag, args[5]);

                imdstKeyValueClient.close();
            } else if (args[0].equals("4")) {

                // ImdstKeyValueClientgpăf[^擾(Tagł̎擾)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] keys = null;
                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]); i++) {
                    Object[] ret = imdstKeyValueClient.getTagKeys(args[4]);
                    if (ret[0].equals("true")) {
                        // f[^L
                        keys = (String[])ret[1];
                        /*for (int i = 0; i < keys.length; i++) {
                            System.out.println(keys[i]);
                        }*/
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }

                if (keys != null) {
                    for (int ii = 0; ii < keys.length; ii++) {
                        System.out.println(keys[ii]);
						String[] ret = imdstKeyValueClient.getValue(keys[ii]);
						System.out.println(ret[1]);
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start));
                imdstKeyValueClient.close();

            } else if (args[0].equals("5")) {

                // ImdstKeyValueClientt@CL[lŕۑ
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] keys = null;
                long start = new Date().getTime();
                // args[4]̓t@CAargs[5]̓L[l
                for (int i = 0; i < Integer.parseInt(args[3]); i++) {
                    // t@CoCiœǂݍ
                    byte[] fileByte = null;
                    File file = new File(args[4]);
                    fileByte = new byte[new Long(file.length()).intValue()];
                    FileInputStream fis = new FileInputStream(file);
                    fis.read(fileByte, 0, fileByte.length);
                    if (!imdstKeyValueClient.setByteValue(args[5], fileByte)) {
                        System.out.println("ImdstKeyValueClient - error");
                    }
                    fis.close();
                }
                long end = new Date().getTime();
                System.out.println((end - start));
                imdstKeyValueClient.close();

            } else if (args[0].equals("6")) {

                // ImdstKeyValueClientgpăf[^擾(Keŷ)(oCi)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                Object[] ret = null;
                long start = new Date().getTime();
                
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    ret = imdstKeyValueClient.getByteValue(args[5]);
                    if (ret[0].equals("true")) {
                        // f[^L
                        byte[] fileByte = null;
                        File file = new File(args[4]);
                        FileOutputStream fos = new FileOutputStream(file);
                        fileByte = (byte[])ret[1];
                        fos.write(fileByte, 0, fileByte.length);
                        fos.close();
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start));
                imdstKeyValueClient.close();
            } else if (args[0].equals("7")) {

                // ImdstKeyValueClientgpăf[^폜
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] ret = null;

                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    ret = imdstKeyValueClient.removeValue("datasavekey_" + new Integer(i).toString());
                    if (ret[0].equals("true")) {
                        // f[^L
                        System.out.println(ret[1]);
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start) + "milli second");

                imdstKeyValueClient.close();
			}

        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}

==> okuyama-0.3.2.zip: okuyama-0.3.2/TestSock.java <==
import java.util.*;
import java.io.*;
import java.net.*;

import org.imdst.client.ImdstKeyValueClient;
import org.batch.lang.BatchException;

public class TestSock {
    public static void main(String[] args) {
        try {
            if (args == null || args.length ==0) {

                System.out.println("{L[lŌJԂϓēo^}                        R}h{args[0]=1, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=o^}");
                System.out.println("{L[lŌJԂϓĎ擾}                        R}h{args[0]=2, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=擾}");
                System.out.println("{Tag4p^[ŎIɕϓăL[l͎ϓœo^}        R}h{args[0]=3, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=o^}");
                System.out.println("{w肵TagŊ֘AL[lw񐔎擾}                       R}h{args[0]=4, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=擾, args[4]=wTagl (tag1 or tag2 or tag3 or tag4)}");
                System.out.println("{w肵t@CoCif[^ƂĎw肵L[lŕۑ}  R}h{args[0]=5, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=o^, args[4]=t@CpX, args[5]=L[l}");
                System.out.println("{w肵L[lŃoCif[^擾ăt@C}          R}h{args[0]=6, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=擾, args[4]=쐬t@CpX, args[5]=L[l}");
                System.out.println("{L[lŌJԂϓč폜}                        R}h{args[0]=7, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=擾}");
                System.out.println("{L[lw肵ăf[^폜}                                    R}h{args[0]=8, args[1]=}X^m[hT[oIP, args[2]=}X^m[hT[oPortԍ, args[3]=폜Keyl}");
                System.exit(0);
            }
            int port = Integer.parseInt(args[2]);

            if (args[0].equals("1")) {

                // ImdstKeyValueClientgpăf[^ۑ(TagȂ)

                // NCAgCX^X쐬
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();

                // }X^T[oɐڑ
                imdstKeyValueClient.connect(args[1], port);

Thread.sleep(100);
                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    // f[^o^
                    if (!imdstKeyValueClient.setValue("datasavekey_" + new Integer(i).toString(), "savedatavaluestr_" + new Integer(i).toString())) {
                        System.out.println("ImdstKeyValueClient - error");
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start) + "milli second");

                imdstKeyValueClient.close();
            } else if (args[0].equals("2")) {

                // ImdstKeyValueClientgpăf[^擾(Keŷ)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] ret = null;
Thread.sleep(100);
                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    ret = imdstKeyValueClient.getValue("datasavekey_" + new Integer(i).toString());
                    if (ret[0].equals("true")) {
                        // f[^L
                        System.out.println(ret[1]);
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start) + "milli second");

                imdstKeyValueClient.close();
            } else if (args[0].equals("2.1")) {

                // ImdstKeyValueClientgpăf[^擾(Keŷ)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] ret = null;

                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    ret = imdstKeyValueClient.getValue("datasavekey_" + new Integer(i).toString());
                    if (ret[0].equals("true")) {
                        // f[^L
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start) + "milli second");

                imdstKeyValueClient.close();

            } else if (args[0].equals("3")) {

                // ImdstKeyValueClientgpăf[^ۑ(Tag)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] tag1 = {"tag1"};
                String[] tag2 = {"tag1","tag2"};
                String[] tag3 = {"tag1","tag2","tag3"};
                String[] tag4 = {"tag4"};
                String[] setTag = null;
                int counter = 0;

                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    if (counter == 0) {
                        setTag = tag1;
                        counter++;
                    } else if (counter == 1) {
                        setTag = tag2;
                        counter++;
                    } else if (counter == 2) {
                        setTag = tag3;
                        counter++;
                    } else if (counter == 3) {
                        setTag = tag4;
                        counter = 0;
                    }

                    if (!imdstKeyValueClient.setValue("tagsampledatakey_" + new Integer(i).toString(), setTag, "tagsamplesavedata_" + new Integer(i).toString())) {
                        System.out.println("ImdstKeyValueClient - error");
                    }
                }

                imdstKeyValueClient.close();
            } else if (args[0].equals("3.1")) {

                // ImdstKeyValueClientgpăf[^ۑ(Tag)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] setTag = args[4].split(" ");

                int counter = 0;
                String keyStr = null;
                imdstKeyValueClient.setValue(args[3], setTag, args[5]);

                imdstKeyValueClient.close();
            } else if (args[0].equals("4")) {

                // ImdstKeyValueClientgpăf[^擾(Tagł̎擾)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] keys = null;
                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]); i++) {
                    Object[] ret = imdstKeyValueClient.getTagKeys(args[4]);
                    if (ret[0].equals("true")) {
                        // f[^L
                        keys = (String[])ret[1];
                        /*for (int idx = 0; idx < keys.length; idx++) {
                            System.out.println(keys[idx]);
                        }*/
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }

                if (keys != null) {
                    for (int ii = 0; ii < keys.length; ii++) {
                        System.out.println("Key=[" + keys[ii] + "]");
                        String[] ret = imdstKeyValueClient.getValue(keys[ii]);
                        System.out.println("Value=[" + ret[1] + "]");
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start));
                imdstKeyValueClient.close();

            } else if (args[0].equals("5")) {

                // ImdstKeyValueClientt@CL[lŕۑ
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] keys = null;
                long start = new Date().getTime();
                // args[4]̓t@CAargs[5]̓L[l
                for (int i = 0; i < Integer.parseInt(args[3]); i++) {
                    // t@CoCiœǂݍ
                    byte[] fileByte = null;
                    File file = new File(args[4]);
                    fileByte = new byte[new Long(file.length()).intValue()];
                    FileInputStream fis = new FileInputStream(file);
                    fis.read(fileByte, 0, fileByte.length);
                    if (!imdstKeyValueClient.setByteValue(args[5], fileByte)) {
                        System.out.println("ImdstKeyValueClient - error");
                    }
                    fis.close();
                }
                long end = new Date().getTime();
                System.out.println((end - start));
                imdstKeyValueClient.close();

            } else if (args[0].equals("6")) {

                // ImdstKeyValueClientgpăf[^擾(Keŷ)(oCi)
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                Object[] ret = null;
                long start = new Date().getTime();
                
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    ret = imdstKeyValueClient.getByteValue(args[5]);
                    if (ret[0].equals("true")) {
                        // f[^L
                        byte[] fileByte = null;
                        File file = new File(args[4]);
                        FileOutputStream fos = new FileOutputStream(file);
                        fileByte = (byte[])ret[1];
                        fos.write(fileByte, 0, fileByte.length);
                        fos.close();
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start));
                imdstKeyValueClient.close();
            } else if (args[0].equals("7")) {

                // ImdstKeyValueClientgpăf[^폜
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] ret = null;

                long start = new Date().getTime();
                for (int i = 0; i < Integer.parseInt(args[3]);i++) {
                    ret = imdstKeyValueClient.removeValue("datasavekey_" + new Integer(i).toString());
                    if (ret[0].equals("true")) {
                        // f[^L
                        System.out.println(ret[1]);
                    } else if (ret[0].equals("false")) {
                        System.out.println("f[^Ȃ");
                    } else if (ret[0].equals("error")) {
                        System.out.println(ret[1]);
                    }
                }
                long end = new Date().getTime();
                System.out.println((end - start) + "milli second");

                imdstKeyValueClient.close();
            } else if (args[0].equals("8")) {
                // ImdstKeyValueClientgpăf[^폜
                ImdstKeyValueClient imdstKeyValueClient = new ImdstKeyValueClient();
                imdstKeyValueClient.connect(args[1], port);
                String[] ret = null;

                long start = new Date().getTime();

                ret = imdstKeyValueClient.removeValue(args[3]);
                if (ret[0].equals("true")) {
                    // f[^L
                    System.out.println(ret[1]);
                } else if (ret[0].equals("false")) {
                    System.out.println("f[^Ȃ");
                } else if (ret[0].equals("error")) {
                    System.out.println(ret[1]);
                }
                long end = new Date().getTime();
                System.out.println((end - start) + "milli second");

                imdstKeyValueClient.close();
            }

        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
